@@ -6,8 +6,6 @@ use strict;
 use Moose;
 extends 'App::PM::Announce::Feed';
 
-has uri => qw/is ro required 1/;
-
 sub announce {
     my $self = shift;
     my %event = @_;
@@ -19,7 +17,7 @@ sub announce {
 
     $self->get( "https://www.linkedin.com/secure/login" );
 
-    $self->logger->debug( "login as $username/$password" );
+    $self->logger->debug( "Login as $username / $password" );
 
     $self->submit_form(
         fields => {
@@ -47,7 +45,9 @@ sub announce {
 
     die "Not sure if discussion was posted" unless $self->content =~ m/Your discussion has been posted successfully/;
 
-    $self->logger->debug( "submitted to linkedin at $uri" );
+    $self->logger->debug( "Submitted to linkedin at $uri" );
+
+    return 1;
 }
 
 1;
